pub struct TxPanic {
    pub status: u64,
    pub message: String,
}
